# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# if sqlite ≥ 3.7.13 then
#   perl-DBD-SQLite uses the system library
# else
#   perl-DBD-SQLite is self-contained (uses the sqlite local copy)
%global use_system_sqlite %((sqlite3 --version 2>/dev/null || echo 0.0.0) | awk -F. '{ ver = sprintf("%d%03d%03d", $1, $2, $3); print ver >= 3007013 ? 1 : 0 }')

Name:		perl-DBD-SQLite
Version:	1.40
Release:	2.%{__distinit}%{__distvers}
Summary:	Self Contained RDBMS in a DBI Driver
Group:		Development/Libraries
License:	GPL+ or Artistic
URL:		http://search.cpan.org/dist/DBD-SQLite/
Source0:	http://search.cpan.org/CPAN/authors/id/I/IS/ISHIGAKI/DBD-SQLite-%{version}.tar.gz
Patch0:		DBD-SQLite-bz543982.patch
Patch1:		https://github.com/DBD-SQLite/DBD-SQLite/commit/f8a45b96f62742351c06fd956a4965004df7226d.patch
Patch2:		https://github.com/DBD-SQLite/DBD-SQLite/commit/6458091dbcf08c5fed462f43a52254e57ef154aa.patch
Patch10:	DBD-SQLite-1.40-utf8.patch
Patch11:	DBD-SQLite-1.39-old-Test::More.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildRequires:	perl(Carp)
BuildRequires:	perl(constant)
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(DBI) >= 1.57
BuildRequires:	perl(Encode)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(File::Spec) >= 0.82
BuildRequires:	perl(File::Spec::Functions)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(Test::More) >= 0.42
BuildRequires:	sqlite-devel
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

# Don't provide private perl objects
%{?perl_default_filter}

%description
SQLite is a public domain RDBMS database engine that you can find at
http://www.sqlite.org/.

%prep
%setup -q -n DBD-SQLite-%{version}

# Build with system SQLite
%if %{use_system_sqlite}
# Enable system sqlite
%patch0
# $(CC) -I. would find the bundled SQLite if these are present
rm -f sqlite3.c sqlite3.h sqlite3ext.h
%endif

# Support SQLite ≥ 3.8.2 (upstream fix)
%patch1 -p1

# Fix test failure in t/53_status.t (upstream fix, CPAN RT#89011)
%patch2 -p1

# Recode docs as UTF8
%patch10

# Work with Test::More < 0.88
%patch11

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -exec rm -f {} ';'
find %{buildroot} -type f -name '*.bs' -a -size 0 -exec rm -f {} ';'
%{_fixperms} %{buildroot}

%check
make test

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc Changes README
%{perl_vendorarch}/auto/DBD/
%if ! %{use_system_sqlite}
%{perl_vendorarch}/auto/share/
%endif
%dir %{perl_vendorarch}/DBD/
%{perl_vendorarch}/DBD/SQLite.pm
%dir %{perl_vendorarch}/DBD/SQLite/
%doc %{perl_vendorarch}/DBD/SQLite/Cookbook.pod
%{_mandir}/man3/DBD::SQLite.3pm*
%{_mandir}/man3/DBD::SQLite::Cookbook.3pm*

%changelog
* Thu Jan 16 2014 Paul Howarth <paul@city-fan.org> - 1.40-2
- Add upstream fix for support of SQLite ≥ 3.8.2
- Add upstream fix for test failure in t/53_status.t (CPAN RT#89011)
- Drop buildreqs needed only for extra tests that aren't run

* Sun Jul 28 2013 Paul Howarth <paul@city-fan.org> - 1.40-1
- Update to 1.40
  - NetBSD also doesn't like the _XOPEN_SOURCE hack
  - Add statistics_info support (CPAN RT#86080)
- Re-diff patches

* Wed Jul 24 2013 Paul Howarth <paul@city-fan.org> - 1.39-2
- Perl 5.18 rebuild

* Sun Jun  9 2013 Paul Howarth <paul@city-fan.org> - 1.39-1
- Update to 1.39 (see Changes for details)
- This release by ISHIGAKI -> update source URL
- Re-diff patches
- Add new patch to support building with Test::More < 0.88
- Build with bundled SQLite unless system version is 3.7.13 or later (fails to
  build with older versions)

* Sat Jul 14 2012 Paul Howarth <paul@city-fan.org> - 1.37-2
- BR: perl(Carp), perl(constant), perl(Data::Dumper), perl(Encode),
  perl(Exporter), perl(File::Spec::Functions) and perl(File::Temp)

* Sat Jun  9 2012 Paul Howarth <paul@city-fan.org> - 1.37-1
- Update to 1.37 (see Changes for details)
- Don't need to remove empty directories from the buildroot
- Use pure_install rather than install
- Re-diff patches
- Build with bundled SQLite unless system version is 3.6.22 or later
  (test t/49_trace_and_profile.t fails otherwise)
- Drop support for old distributions prior to FC-3:
  - Always BR: sqlite-devel
  - Don't need to define %%{perl_vendorarch}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Use %%{_fixperms} macro rather than our own chmod incantation

* Tue Nov 29 2011 Paul Howarth <paul@city-fan.org> - 1.35-1
- Update to 1.35 (see Changes for details)
- Re-diff UTF-8 patch

* Thu Jun 23 2011 Paul Howarth <paul@city-fan.org> - 1.33-2
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Mon May 30 2011 Paul Howarth <paul@city-fan.org> - 1.33-1
- Update to 1.33 (see Changes for details)
- Drop upstreamed patch for building with system SQLite
- Re-diff UTF-8 patch
- Nobody else likes macros for commands

* Fri Oct  1 2010 Paul Howarth <paul@city-fan.org> - 1.31-2
- Rebuild for gcc bug (#634757)

* Wed Sep 15 2010 Paul Howarth <paul@city-fan.org> - 1.31-1
- Update to 1.31 (see Changes for details)
- Update UTF-8 patch
- Remove bundled SQLite if we're building with system version
- Add patch to support building with a system SQLite that's not built with
  the ENABLE_FTS3_PARENTHESIS option

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 1.29-3
- Rebuild for perl 5.12.1 in Rawhide

* Tue Jun  1 2010 Paul Howarth <paul@city-fan.org> - 1.29-2
- Fix dist tag for RHEL-6 Beta

* Mon Apr 12 2010 Paul Howarth <paul@city-fan.org> - 1.29-1
- Import from Fedora
- Update to 1.29
- Enable AUTOMATED_TESTING

* Mon Jan 11 2010 Marcela Mašláňová <mmaslano@redhat.com> - 1.27-3
- 543982 change Makefile.PL to compile with system sqlite

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 1.27-2
- Rebuild against perl 5.10.1

* Wed Nov 25 2009 Stepan Kasal <skasal@redhat.com> 1.27-1
- New upstream version

* Fri Sep 11 2009 Chris Weyl <cweyl@alumni.drew.edu> - 1.25-4
- Filtering errant private provides

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.25-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Jun 10 2009 Stepan Kasal <skasal@redhat.com> - 1.25-2
- Rebuild against DBI 1.609

* Fri May 29 2009 Chris Weyl <cweyl@alumni.drew.edu> - 1.25-1
- 1.25 needed for DBIx::Class 0.08103
- Auto-update to 1.25 (by cpan-spec-update 0.01)
- Added a new br on perl(File::Spec) (version 0.82)
- Altered br on perl(Test::More) (0 => 0.42)
- Added a new br on perl(DBI) (version 1.57)

* Mon Apr 20 2009 Marcela Maslanova <mmaslano@redhat.com> - 1.23-1
- Update to the latest version

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.14-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Jun  2 2008 Marcela Maslanova <mmaslano@redhat.com> - 1.14-8

* Wed Mar 19 2008 Chris Weyl <cweyl@alumni.drew.edu> - 1.14-7
- Reenable tests

* Tue Mar 18 2008 Chris Weyl <cweyl@alumni.drew.edu> - 1.14-6
- Apply sanity patches derived from RT#32100

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.14-5.1
- Rebuild for perl 5.10 (again)

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 1.14-4.1
- Autorebuild for GCC 4.3

* Sun Jan 20 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.14-3.1
- Tests disabled, due to x86_64 failures

* Tue Jan 15 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.14-3
- Rebuild for new perl

* Wed Dec 19 2007 Steven Pritchard <steve@kspei.com> - 1.14-2
- Fix find option order
- Use fixperms macro instead of our own chmod incantation

* Mon Dec 10 2007 Robin Norwood <rnorwood@redhat.com> - 1.14-1
- Update to latest upstream version: 1.14
- Remove patch - no longer needed.

* Mon Oct 15 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 1.12-2.1
- Correct license tag
- Add BR: perl(ExtUtils::MakeMaker)

* Thu Sep 14 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.12-2
- Rebuild for FC6

* Tue Apr 11 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.12-1
- Update to 1.12

* Wed Apr  5 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.11-4
- Patch to build with system sqlite 3.3.x (#183530)
- Patch to avoid type information segv (#187873)

* Thu Mar  9 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.11-3
- DBD::SQLite fails to build with the current FC-5 sqlite version (3.3.3);
  see bugzilla entry #183530
- Forcing package rebuild with the included version of sqlite (3.2.7)

* Sat Feb 18 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.11-2
- Rebuild for FC5 (perl 5.8.8)

* Fri Dec  2 2005 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.11-1
- Update to 1.11

* Fri Dec  2 2005 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.10-1
- Update to 1.10

* Fri Jul 29 2005 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.09-2
- Build requirement added: sqlite-devel
- Doc file added: Changes

* Fri Jul 29 2005 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.09-1
- Update to 1.09
- This new version can use an external SQLite library (>= 3.1.3)

* Sun Jun 12 2005 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.08-2
- Temporary maintainership

* Sat Jun 11 2005 Michael A. Peters <mpeters@mac.com> - 1.08-1.1
- Minor changes for initial cvs checkin (removed tabs, better url in
  url tag and description tag)

* Tue Apr 12 2005 Michael A. Peters <mpeters@mac.com> - 1.08-1
- Created initial spec file from Fedora spectemplate-perl.spec
